package com.taais.biz.service.impl;

import java.util.Arrays;
import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryWrapper;
import com.taais.common.core.utils.MapstructUtils;
import com.taais.common.core.utils.StringUtils;
import com.taais.common.orm.core.page.PageQuery;
import com.taais.common.core.core.page.PageResult;
import com.taais.common.orm.core.service.impl.BaseServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.taais.biz.mapper.TargetIdentificationSubtaskMapper;
import com.taais.biz.domain.TargetIdentificationSubtask;
import com.taais.biz.domain.bo.TargetIdentificationSubtaskBo;
import com.taais.biz.domain.vo.TargetIdentificationSubtaskVo;
import com.taais.biz.service.ITargetIdentificationSubtaskService;
import static com.taais.biz.domain.table.TargetIdentificationSubtaskTableDef.TARGET_IDENTIFICATION_SUBTASK;

/**
 * 目标识别子任务Service业务层处理
 *
 * @author Allen
 * 2024-08-17
 */
@Service
public class TargetIdentificationSubtaskServiceImpl extends BaseServiceImpl<TargetIdentificationSubtaskMapper, TargetIdentificationSubtask> implements ITargetIdentificationSubtaskService {
    @Resource
    private TargetIdentificationSubtaskMapper targetIdentificationSubtaskMapper;

    @Override
    public QueryWrapper query() {
        return super.query().from(TARGET_IDENTIFICATION_SUBTASK);
    }

    private QueryWrapper buildQueryWrapper(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo) {
        QueryWrapper queryWrapper = super.buildBaseQueryWrapper();
        queryWrapper.and(TARGET_IDENTIFICATION_SUBTASK.NAME.like
        (targetIdentificationSubtaskBo.getName()));
        queryWrapper.and(TARGET_IDENTIFICATION_SUBTASK.STATUS.eq
        (targetIdentificationSubtaskBo.getStatus()));
        queryWrapper.and(TARGET_IDENTIFICATION_SUBTASK.REMARKS.eq
        (targetIdentificationSubtaskBo.getRemarks()));
        return queryWrapper;
    }

    /**
     * 查询目标识别子任务
     *
     * @param id 目标识别子任务主键
     * @return 目标识别子任务
     */
    @Override
    public TargetIdentificationSubtaskVo selectById(Long id) {
            return this.getOneAs(query().where(TARGET_IDENTIFICATION_SUBTASK.ID.eq(id)), TargetIdentificationSubtaskVo.class);

    }

    /**
     * 查询目标识别子任务列表
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 目标识别子任务集合
     */
    @Override
    public List<TargetIdentificationSubtaskVo> selectList(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(targetIdentificationSubtaskBo);
            return this.listAs(queryWrapper, TargetIdentificationSubtaskVo.class);
    }

    /**
     * 分页查询目标识别子任务列表
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 分页目标识别子任务集合
     */
    @Override
    public PageResult<TargetIdentificationSubtaskVo> selectPage(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(targetIdentificationSubtaskBo);
            Page<TargetIdentificationSubtaskVo> page = this.pageAs(PageQuery.build(), queryWrapper, TargetIdentificationSubtaskVo.class);
        return PageResult.build(page);
    }

    /**
     * 新增目标识别子任务
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    @Override
    public boolean insert(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo) {
    TargetIdentificationSubtask targetIdentificationSubtask =MapstructUtils.convert(targetIdentificationSubtaskBo, TargetIdentificationSubtask. class);

        return this.save(targetIdentificationSubtask);//使用全局配置的雪花算法主键生成器生成ID值
    }

    /**
     * 修改目标识别子任务
     *
     * @param targetIdentificationSubtaskBo 目标识别子任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    @Override
    public boolean update(TargetIdentificationSubtaskBo targetIdentificationSubtaskBo) {
        TargetIdentificationSubtask targetIdentificationSubtask =MapstructUtils.convert(targetIdentificationSubtaskBo, TargetIdentificationSubtask. class);
        if (ObjectUtil.isNotNull(targetIdentificationSubtask) && ObjectUtil.isNotNull(targetIdentificationSubtask.getId())){
            boolean updated = this.updateById(targetIdentificationSubtask);
                return updated;
        }
        return false;
    }

    /**
     * 批量删除目标识别子任务
     *
     * @param ids 需要删除的目标识别子任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    @Transactional
    @Override
    public boolean deleteByIds(Long[] ids) {
        return this.removeByIds(Arrays.asList(ids));
    }

}
